#brockp@umich.edu
#blender 2.72
# BMW1M-MikePan.blend
# http://blenderartists.org/forum/showthread.php?239480-2-6x-Cycles-render-benchmark
# run with: blender -b --python bmw.py
 
import bpy
import os

#read and switch temporary files directory
if 'SCRATCHDIR' in os.environ:
    # temporary files will go to distributed scratch directory on Lustre fileststem:
    bpy.types.UserPreferencesFilePaths.temporary_directory =  os.environ['SCRATCHDIR']
    bpy.types.UserPreferencesFilePaths.render_cache_directory = os.environ['SCRATCHDIR']
elif 'TMPDIR' in os.environ:
    # temporary files will go to scratch directory located on WNs local filesystem
    bpy.types.UserPreferencesFilePaths.temporary_directory =  os.environ['TMPDIR']
    bpy.types.UserPreferencesFilePaths.render_cache_directory = os.environ['TMPDIR']
 
#read our input blend
bpy.ops.wm.open_mainfile(filepath="BMW1M-MikePan.blend")
 
#Switch Engine to Cycles
bpy.context.scene.render.engine = 'CYCLES'
 
#tell blender to use CUDA / GPU devices
bpy.context.user_preferences.system.compute_device_type = 'CUDA'
 
#set CYCLES render system GPU or CPU
# GPU, CPU
bpy.data.scenes["Scene"].cycles.device='GPU'
 
#### THIS IS IMPORTANT FOR PERFORMANCE, see link
#for GPU rendering set the tile size large
# http://adaptivesamples.com/2013/11/05/auto-tile-size-addon-updated-again/
# GPU = 256x256
# CPU = 16x16
bpy.context.scene.render.tile_x = 256
bpy.context.scene.render.tile_y = 256
 
#set the format we want our image saved as, and file name/location
bpy.context.scene.render.image_settings.file_format = 'PNG'
bpy.data.scenes['Scene'].render.filepath = './bmw-gpgpu'
 
#pull the trigger
bpy.ops.render.render(write_still=True) 

# Erasing files from distributed scratch directory on Lustre filesystem:
if 'SCRATCHDIR' in os.environ:
    for (root, dirs, files) in os.walk(os.environ['SCRATCHDIR'],topdown=False):
        for name in files:
            os.remove(os.path.join(root, name))
        for name in dirs:
            os.rmdir(os.path.join(root, name))
    os.rmdir(os.environ['SCRATCHDIR'])
